jQuery(document).ready(function ($) {

    // Highlight corresponding regex groups and their targets in the "Substitution" column
    $('span.regexgroup, span.regexgroup-target').hover(
        function () {
            var id = $(this)[0].id;
            if (id.substr(-7) == '-target') {
                id = id.substr(0, id.length - 7);
            }
            $('#' + id + ', #' + id + '-target').toggleClass('highlight');
        }
    );

    // Highlight the target of a repeater
    $('span.regex-repeater').hover(
        function () {
            $(this).parent().toggleClass('highlight');
        }
    );

    var idxFirstMatchedRewriteRule = null;

    $('#regex-tester').keyup(function () {
        var url = $(this).val();
        if ('' == url) {
            // Empty box, show all rules
            $('.rewrite-rule-line').removeClass('rewrite-rule-matched rewrite-rule-matched-first rewrite-rule-unmatched');
            return;
        }

        var matchedRules = {};
        var result;
        var isFirst = true;
        for (var idx in Rewrite_Analyzer_Regexes) {
            if (result = Rewrite_Analyzer_Regexes[idx].exec(url)) {
                // If it is a match, show it
                matchedRules[idx] = result;
                var elRule = $('#rewrite-rule-' + idx).addClass('rewrite-rule-matched').removeClass('rewrite-rule-unmatched');

                // Fill in the corresponding query values
                for (var rIdx = 0; rIdx < result.length; rIdx++) {
                    $('#regex-' + idx + '-group-' + rIdx + '-target-value').html(result[rIdx] || '');
                }

                if (isFirst) {
                    // If it is the first match, highlight it
                    elRule.addClass('rewrite-rule-matched-first');
                    isFirst = false;
                    if (idxFirstMatchedRewriteRule != idx) {
                        // The previous first match is not longer the first match
                        $('#rewrite-rule-' + idxFirstMatchedRewriteRule).removeClass('rewrite-rule-matched-first');
                        idxFirstMatchedRewriteRule = idx;
                    }
                }
            } else {
                // If it is not a match, hide it
                $('#rewrite-rule-' + idx).removeClass('rewrite-rule-matched').addClass('rewrite-rule-unmatched');
            }
        }
    });

    // Clear the tester and show all rules
    $('#_regex-search-bar').on('click', function () {
        $('#regex-tester').val('');
        $('.rewrite-rule-line').removeClass('rewrite-rule-matched rewrite-rule-matched-first rewrite-rule-unmatched');
    });

    // Compile all regexes
    for (var idx in Rewrite_Analyzer_Regexes) {
        var pattern = Rewrite_Analyzer_Regexes[idx];
        var regex = new RegExp('^' + pattern);
        Rewrite_Analyzer_Regexes[idx] = regex;
    }

    $('#flush-rewrite-rules').on('click', function () {
        let $this = $(this);
        $this.addClass('rotate');
        // Ajax Call
        $.post({
            url: admin.ajax_url,
            data: {
                action: "refresh_permalinks",
            },
            success: function (response) {
                var answer = response.data;
                $this.removeClass('rotate');
                if (answer) {
                    $this.find('span').html('Permalinks refreshed');
                }
                setTimeout(() => {
                    $this.find('span').html('Refresh permalinks');
                }, 3000);

            },
        });
    })

    // BackToTop button
    let $scrollToTopWrapper = $('.urap-btt-wrapper');
    let $scrollToTopButton = $scrollToTopWrapper.find('button');
    $(window).on('scroll', function () {
        if (document.body.scrollTop > 20 || document.documentElement.scrollTop > 20) {
            $scrollToTopWrapper.addClass('open');
        } else {
            $scrollToTopWrapper.removeClass('open');
        }
    })
    $scrollToTopButton.on('click', function () {
        $(window).scrollTop(0)
    })

    // Change UI
    let changeUIButton = $('#update-ui');
    changeUIButton.on('click', function () {
        let $this = $(this);
        let $modal = $this.closest('.wrap').find('.modal-change-ui');
        let $head_wrapper = $modal.next();
        $modal.toggleClass('open');
        $head_wrapper.toggleClass('open');
    })

    // Radio Button
    $('.modal-change-ui .ui-select').click(function () {
        let val = $(this).next().val();
        $('.modal-change-ui .ui-select').not($(this)).removeClass('selected');
        $(this).addClass('selected');
        // Ajax Call
        $.post({
            url: admin.ajax_url,
            data: {
                action: "change_ui",
                style: val,
            },
            success: function (response) {
                window.location.reload();
            },
        });
    })

});